@@ -5,20 +5,22 @@ import numpy as np
 import pandas as pd
 import spacy
 from spacy.cli import download
+import os
+
 
 download("en")
 nlp = spacy.load("en")
 
 
 class CleanText:
-    # def __init__(self):
-    #     self.all_names = pd.read_pickle("data/all_names")
-
-    # def remove_names(self, text):
-    #     cleaned_text = text
-    #     for i, row in self.all_names.iterrows():
-    #         cleaned_text = re.sub(row["name"] + "[^\w\s]*[\s]+", " ", cleaned_text)
-    #     return cleaned_text
+    def remove_names(self, text):
+        all_names = pd.read_pickle(
+            os.path.join(os.path.dirname(__file__), "data/all_names")
+        )
+        cleaned_text = text
+        for i, row in all_names.iterrows():
+            cleaned_text = re.sub(row["name"] + "[^\w\s]*[\s]+", " ", cleaned_text)
+        return cleaned_text
 
     def remove_links(self, text):
         """
