@@ -3,7 +3,7 @@ from datto.Experiments import Experiments
 from datto.DataConnections import SQLConnections
 from datto.DataConnections import S3Connections
 from datto.DataConnections import KafkaInterface
-from datto.Setup import Setup
+from datto.SetupMethods import SetupMethods
 from datto.TrainModel import TrainModel
 from datto.ModelResults import ModelResults
 from datto.FrontEnd import FrontEnd
